<?php

   header('Pragma: public');
   header('Content-type: text/plain; charset=UTF-8');
   header('Cache-Control: private');
   header('Cache-Control: no-cache, must-revalidate');
   
// Script ssHWAFeed.php is Annex to Meteotemplate with the purpose to provide a socalled HWA-file to the server at HetWeerActueel.nl
// Such HWA-file contains all required data in a specific format to feed the database at the website of HetWeerActueel from a specific weather station.
// Resulting from the upload of the HWA-file is presentation of meteo-data of the subject weather station in tables and graphs, as well as in historical surveys.
// 
// Derived from Jachym's script ssMeteotemplate.php v4 for Meteotemplate.
// That script extended/adapted by Toulon7559 with segments from other scripts in the Meteotemplate-package, and from other material provided by Jachym.
// This method of construction is on purpose to stay as close as possible to the existing structure of Meteotemplate.
// This script ssHWAFeed.php has to be installed in the folder <your-webhoster>//template/plugins/ side-by-side with script ssMeteotemplate.php
// No need to perform any settings in Meteotemplate: the script just takes data and settings from information already available within Meteotemplate.
// The HWA-server will call this script by url-call https://<your-webhoster>/template/plugins/ssHWAFeed.php at which call the script will generate the HWA-file.
// (c)2022, version 0.22; Jachym & Toulon7559 & wsEpe

    include("../../config.php");
    include("../../scripts/functions.php");

// UV data not in database - cache if no extra database 
	$sensorUV = 0;  
	$uvcache = 0;
	$uvdatabase = 0;
	$uvfromcache['maxdata'] = '---'; //cache
	$uvfromcache['maxtime'] = '---';
	$maxUVToday = '---';		//db
	$maxUVtime = '---';
	$hiUV = '---';			//hwa
	$hiUVTime = '---';
	
    if(!is_dir("cache")){
		mkdir("cache");			
	}
	if(!file_exists("cache/uv.txt")){
		$toCache['maxdate'] = '01/01/2020]';
		$toCache['maxtime'] = '00:00';
		$toCache['maxdata'] = '0';
		file_put_contents("cache/uv.txt",json_encode($toCache));
	}
	
// GET CURRENT DATA
    $apiData = file_get_contents("../../meteotemplateLive.txt");
    $apiData = json_decode($apiData,true);
    $current['T'] = number_format(convertor($apiData['T'],"C",$displayTempUnits),1,".","");
    $current['H'] = number_format($apiData['H'],1,".","");
    if($displayPressUnits=="hpa"){
        $current['P'] = number_format(convertor($apiData['P'],"hpa",$displayPressUnits),1,".","");
    }
    else{
        $current['P'] = number_format(convertor($apiData['P'],"hpa",$displayPressUnits),2,".","");
    }
    $current['W'] = number_format(convertor($apiData['W'],"kmh",$displayWindUnits),1,".","");
    $current['G'] = number_format(convertor($apiData['G'],"kmh",$displayWindUnits),1,".","");
    if($displayRainUnits=="mm"){
        $current['R'] = number_format(convertor($apiData['R'],"mm",$displayRainUnits),1,".","");
        $current['RR'] = number_format(convertor($apiData['RR'],"mm",$displayRainUnits),1,".","");
    }
    else{
        $current['R'] = number_format(convertor($apiData['R'],"mm",$displayRainUnits),2,".","");
        $current['RR'] = number_format(convertor($apiData['RR'],"mm",$displayRainUnits),2,".","");
    }
    $current['D'] = number_format(convertor($apiData['D'],"C",$displayTempUnits),1,".","");
    $current['A'] = number_format(convertor($apiData['A'],"C",$displayTempUnits),1,".","");
    $current['B'] = $apiData['B'];
    $current['S'] = $apiData['S'];
	
    if(isset($apiData['UV'])){
       	$current['UV'] = number_format($apiData['UV'],1,".","");
		$sensorUV=1;
	}
    else{
        $current['UV'] = "---";
    }
	    if(isset($apiData['SS'])){
        $current['SS'] = $apiData['SS'];
    }
    else{
        $current['SS'] = "---";
    }
	
	$current['Timestamp'] = $apiData['U'];
	$current['UNIX'] = $apiData['U'];


					
    if($displayPressUnits=="inhg"){
        $decimalsP = 2;
    }
    else{
        $decimalsP = 1;
    }
    if($displayRainUnits=="in"){
        $decimalsR = 2;
    }
    else{
        $decimalsR = 1;
    }
	
// GET HIGH/LOW + TIME from db alldata

    $result = mysqli_query($con,"
		SELECT *
		FROM alldata
		WHERE DATE(DateTime) = CURDATE()
        ORDER BY DateTime
	"
	);
	while($row = mysqli_fetch_array($result)){
        $thisTime = date($timeFormat,strtotime($row['DateTime']));
        // max T
        if(isset($today['maxT'])){
            if($today['maxT']<=convertT($row['Tmax'])){
                $today['maxT'] = convertT($row['Tmax']);
                $today['maxTTime'] = $thisTime;
            }
        }
        else{
            $today['maxT'] = convertT($row['Tmax']);
            $today['maxTTime'] = $thisTime;
        }
        // min T
        if(isset($today['minT'])){
            if($today['minT']>=convertT($row['Tmin'])){
                $today['minT'] = convertT($row['Tmin']);
                $today['minTTime'] = $thisTime;
            }
        }
        else{
            $today['minT'] = convertT($row['Tmin']);
            $today['minTTime'] = $thisTime;
        }
        // max H
        if(isset($today['maxH'])){
            if($today['maxH']<=($row['H'])){
                $today['maxH'] = ($row['H']);
                $today['maxHTime'] = $thisTime;
            }
        }
        else{
            $today['maxH'] = ($row['H']);
            $today['maxHTime'] = $thisTime;
        }
        // min H
        if(isset($today['minH'])){
            if($today['minH']>=($row['H'])){
                $today['minH'] = ($row['H']);
                $today['minHTime'] = $thisTime;
            }
        }
        else{
            $today['minH'] = ($row['H']);
            $today['minHTime'] = $thisTime;
        }
        // max P
        if(isset($today['maxP'])){
            if($today['maxP']<=convertP($row['P'])){
                $today['maxP'] = convertP($row['P']);
                $today['maxPTime'] = $thisTime;
            }
        }
        else{
            $today['maxP'] = convertP($row['P']);
            $today['maxPTime'] = $thisTime;
        }
        // min P
        if(isset($today['minP'])){
            if($today['minP']>=convertP($row['P'])){
                $today['minP'] = convertP($row['P']);
                $today['minPTime'] = $thisTime;
            }
        }
        else{
            $today['minP'] = convertP($row['P']);
            $today['minPTime'] = $thisTime;
        }
        // max A
        if(isset($today['maxA'])){
            if($today['maxA']<=convertT($row['A'])){
                $today['maxA'] = convertT($row['A']);
                $today['maxATime'] = $thisTime;
            }
        }
        else{
            $today['maxA'] = convertT($row['A']);
            $today['maxATime'] = $thisTime;
        }
        // min T
        if(isset($today['minA'])){
            if($today['minA']>=convertT($row['A'])){
                $today['minA'] = convertT($row['A']);
                $today['minATime'] = $thisTime;
            }
        }
        else{
            $today['minA'] = convertT($row['A']);
            $today['minATime'] = $thisTime;
        }
        // max D
        if(isset($today['maxD'])){
            if($today['maxD']<=convertT($row['D'])){
                $today['maxD'] = convertT($row['D']);
                $today['maxDTime'] = $thisTime;
            }
        }
        else{
            $today['maxD'] = convertT($row['D']);
            $today['maxDTime'] = $thisTime;
        }
        // min D
        if(isset($today['minD'])){
            if($today['minD']>=convertT($row['D'])){
                $today['minD'] = convertT($row['D']);
                $today['minDTime'] = $thisTime;
            }
        }
        else{
            $today['minD'] = convertT($row['D']);
            $today['minDTime'] = $thisTime;
        }
        // max W
        if(isset($today['maxW'])){
            if($today['maxW']<=convertW($row['W'])){
                $today['maxW'] = convertW($row['W']);
                $today['maxWTime'] = $thisTime;
            }
        }
        else{
            $today['maxW'] = convertW($row['W']);
            $today['maxWTime'] = $thisTime;
        }
        // max G
        if($type!="cumulus"){
            if(isset($today['maxG'])){
                if($today['maxG']<=convertW($row['G'])){
                    $today['maxG'] = convertW($row['G']);
                    $today['maxGTime'] = $thisTime;
                }
            }
            else{
                $today['maxG'] = convertW($row['G']);
                $today['maxGTime'] = $thisTime;
            }
        }
        // max RR
        if(isset($today['maxRR'])){
            if($today['maxRR']<=convertR($row['RR'])){
                $today['maxRR'] = convertR($row['RR']);
                $today['maxRRTime'] = $thisTime;
            }
        }
        else{
            $today['maxRR'] = convertR($row['RR']);
            $today['maxRRTime'] = $thisTime;
        }
        // max S
        if(isset($today['maxS'])){
            if($today['maxS']<=($row['S'])){
                $today['maxS'] = ($row['S']);
                $today['maxSTime'] = $thisTime;
            }
        }
        else{
            $today['maxS'] = ($row['S']);
            $today['maxSTime'] = $thisTime;
        }


        $bearings[] = $row['B'];
        $winds[] = convertW($row['W']);

        $currentDirection = windAbb($row['B']);
        $direction[$currentDirection] = $direction[$currentDirection] + 1;
    }

	
	//	get trend T and P 	
    $result = mysqli_query($con,"
		SELECT T, P
		FROM alldata
		WHERE DateTime > DATE_SUB(NOW(), INTERVAL 1 HOUR)
        ORDER BY DateTime
        LIMIT 1
	"
	);
	while($row = mysqli_fetch_array($result)){
        $trend['T'] = $current['T'] - convertT($row['T']);
        $trend['P'] = $current['P'] - convertP($row['P']);
    }

    $today['avgW'] = array_sum($winds)/count($winds);
    $today['avgB'] = avgWind($bearings);
    $today['dominantWind'] = windAbb($today['avgB']);
    $today['direction'] = $direction;
	
// UV - check UV in db // get max uv
		
		if(file_exists("../../update/apiSettings.txt")){
			$apiSetup = file_get_contents("../../update/apiSettings.txt");
			$apiSetup = json_decode($apiSetup,1);
			if($apiSetup['UV'] == 1) { //uv in db
				$uvdatabase = 1;
				$result = mysqli_query($con, "
					SELECT max(UV)
					FROM  alldataExtra
					WHERE DATE(DateTime) = CURDATE()
					"
				);
				while ($row = mysqli_fetch_array($result)) {
					$maxUVToday = $row['max(UV)'];
					$maxUVToday = $maxUVToday < $UV ? $UV : $maxUVToday;
					$maxUVorig = $maxUVToday;
					//$today['maxUV'] = $row['max(UV)'];
				}
				
				$result = mysqli_query($con, "
					SELECT  DateTime
					FROM  alldataExtra
					WHERE UV = $maxUVorig AND DATE(DateTime) = CURDATE()
					ORDER BY DateTime DESC
					LIMIT 1
					"
				);
				while ($row = mysqli_fetch_array($result)) {
					$maxUVtime = strtotime($row['DateTime']);
					$maxUVtime = date($timeFormat,$maxUVtime);
				}
			
			} 
		}
		
// UV - check UV in cache // get max uv
		if ($sensorUV == 1) { 
				$writecache = 0;
				$uvcache = 1;
				$uv2cache['uv'] = $current['UV'];  //current uv / date
				$uv2cache['uvdate'] = date('d-m-Y',$current['UNIX']);
				$uv2cache['uvtime'] = date('H:i',$current['UNIX']);

				if(file_exists("cache/uv.txt")){
					$uvfromcache = json_decode(file_get_contents("cache/uv.txt"),true);
					
						if(isset($uvfromcache['maxdata'])){ 
								if ($uvfromcache['maxdate']<($uv2cache['uvdate'])){  //new day reset uv current uv / date
												$uvfromcache['maxdata'] = ($current['UV']);   
												$uvfromcache['maxdate'] = ($uv2cache['uvdate']);
												$uvfromcache['maxtime'] = ($uv2cache['uvtime']);
											$writecache = 1;												
								}
								elseif ($uvfromcache['maxdata']<=($current['UV'])){   //check current uv is new high 
												$uvfromcache['maxdata'] = ($current['UV']); 
												$uvfromcache['maxdate'] = ($uv2cache['uvdate']);
												$uvfromcache['maxtime'] = ($uv2cache['uvtime']);
											$writecache = 1;
								}
								else {		$writecache = 0; //uv cache is higher dan current uv; no update
																					
								}
						}
				}
 
				if($writecache == 1){ //save new uv high to cache
						$toCache['maxdate'] = $uvfromcache['maxdate'];
						$toCache['maxtime'] = $uvfromcache['maxtime'];
						$toCache['maxdata'] = $uvfromcache['maxdata'];
						file_put_contents("cache/uv.txt",json_encode($toCache));
				}
		} 

		
// check if the record value was not yet logged in db
    if($current['T']>=$today['maxT']){
        $today['maxT'] = $current['T'];
        $today['maxTTime'] = date('H:i',$current['UNIX']);
    }
    if($current['T']<=$today['minT']){
        $today['minT'] = $current['T'];
        $today['minTTime'] = date('H:i',$current['UNIX']);
    }
    if($current['A']>=$today['maxA']){
        $today['maxA'] = $current['A'];
        $today['maxATime'] = date('H:i',$current['UNIX']);
    }
    if($current['A']<=$today['minA']){
        $today['minA'] = $current['A'];
        $today['minATime'] = date('H:i',$current['UNIX']);
    }
    if($current['D']>=$today['maxD']){
        $today['maxD'] = $current['D'];
        $today['maxDTime'] = date('H:i',$current['UNIX']);
    }
    if($current['D']<=$today['minD']){
        $today['minD'] = $current['D'];
        $today['minDTime'] = date('H:i',$current['UNIX']);
    }
    if($current['H']>=$today['maxH']){
        $today['maxH'] = $current['H'];
        $today['maxHTime'] = date('H:i',$current['UNIX']);
    }
    if($current['H']<=$today['minH']){
        $today['minH'] = $current['H'];
        $today['minHTime'] = date('H:i',$current['UNIX']);
    }
    if($current['P']>=$today['maxP']){
        $today['maxP'] = $current['P'];
        $today['maxPTime'] = date('H:i',$current['UNIX']);
    }
    if($current['P']<=$today['minP']){
        $today['minP'] = $current['P'];
        $today['minPTime'] = date('H:i',$current['UNIX']);
    }  
    if($current['G']>=$today['maxG']){
        $today['maxG'] = $current['G'];
        $today['maxGTime'] = date('H:i',$current['UNIX']);
    }
    if($current['S']>=$today['maxS']){
        $today['maxS'] = $current['S'];
        $today['maxSTime'] = date('H:i',$current['UNIX']);
    }
    if($current['RR']>=$today['maxRR']){
        $today['maxRR'] = $current['RR'];
        $today['maxRRTime'] = date('H:i',$current['UNIX']);
    }
//check if the UV high record value was not yet logged in db
	if ($uvdatabase == 1) {
		if($current['UV'] >= $maxUVToday){
			$maxUVToday = $current['UV'];
			$maxUVtime = date('H:i',$current['UNIX']);
		}
	} 

    $windNames = array("N","NNE","NE","ENE","E","ESE","SE","SSE","S","SSW","SW","WSW","W","WNW","NW","NNW");
    $windRose = array();
    foreach($windNames as $windName){
        if(isset($today['direction'][$windName])){
            $windRose[] = $today['direction'][$windName];
        }
        else{
            $windRose[] = 0;
        }
    }

    $todayElapsed = strtotime(date("Y")."-".date('m')."-".date("d")." ".$current['Timestamp']) - strtotime(date("Y")."-".date('m')."-".date("d"));

    $windRun = ($today['avgW'])*($todayElapsed/(60*60));
    if($displayWindUnits=="ms"){
        $windRun = $windRun * 3.6;
    }

	function apparent($T,$H,$W){
		$T = ($T-32)/1.8;
		$e = ($H/100)*6.105*pow(2.71828, ((17.27*$T)/(237.7+$T)));
		$A = round(($T + 0.33*$e-0.7*$W-4),1);
		$A = ($A*1.8)+32;
		return $A;
	}
	function apparentWeatherCat($T,$H,$W){
		$e = ($H/100)*6.105*pow(2.71828, ((17.27*$T)/(237.7+$T)));
		$A = round(($T + 0.33*$e-0.7*$W-4),1);
		return $A;
	}
	function apparentWD($T,$H,$W){
		$e = ($H/100)*6.105*pow(2.71828, ((17.27*$T)/(237.7+$T)));
		$A = round(($T + 0.33*$e-0.7*$W-4),1);
		return $A;
	}
	function dewpointWeatherCat($T,$H){
		$D = round(((pow(($H/100), 0.125))*(112+0.9*$T)+(0.1*$T)-112),1);
		return $D;
	}
	function dewpoint($T,$H){
		$D = round(((pow(($H/100), 0.125))*(112+0.9*$T)+(0.1*$T)-112),1);
		return $D;
	}
    function steelUnits($unit){
        if($unit=="inhg"){
            return "inHg";
        }
        if($unit=="hpa"){
            return "hPa";
        }
        if($unit=="ms"){
            return "m/s";
        }
        if($unit=="km/h"){
            return "kmh";
        }
        if($unit=="kt"){
            return "kts";
        }
        else{
            return $unit;
        }
    }

    //Calculation of Sunrise & Sunset, 'borrowed & adapted' from template/pages/astronomy/sunAjax.php
        $lat = $stationLat;
	$lon = $stationLon;
	
	//$y = $_GET['y'];
	//$m = $_GET['m'];
	//$d = $_GET['d'];
	
	$dateTimeZone = new DateTimeZone($stationTZ);
	$dateTime = new DateTime("now", $dateTimeZone);
	$my = $dateTimeZone->getOffset($dateTime);
	$offset = $my/3600;
	
	//$dateComplete = $m."/".$d."/".$y;
	$dateComplete = date("m/d/Y");
	
	$dayStart = date("U",strtotime($dateComplete." 00:00"));
	$dayEnd = date("U",strtotime($dateComplete." 23:59"));
	
	/*Normal*/
	$sunRise=date_sunrise(strtotime($dateComplete),SUNFUNCS_RET_STRING,$lat,$lon,90.5,$offset);
	$sunRiseGraph=date_sunrise(strtotime($dateComplete),SUNFUNCS_RET_TIMESTAMP,$lat,$lon,90.5,$offset);
	$sunSet=date_sunset(strtotime($dateComplete),SUNFUNCS_RET_STRING,$lat,$lon,90.5,$offset);
	$sunSetGraph=date_sunset(strtotime($dateComplete),SUNFUNCS_RET_TIMESTAMP,$lat,$lon,90.5,$offset);

	$diff = round(($sunSetGraph - $sunRiseGraph)/2/60);
	$str = "+ ".$diff." minute";
	
	$sunRiseTime = strtotime($dateComplete." ".$sunRise);
	$transitTime = strtotime($str,$sunRiseTime);
	$transit = date('H:i', $transitTime);
	$sunSetTime = strtotime($dateComplete." ".$sunSet);

	$diff = ($sunSetGraph-$sunRiseGraph)/60;
	$diffN = 1441 - $diff;
	$diffM = $diff % 60;
	if($diffM<10){
		$diffM = "0".$diffM;
	}
	$diffNM = $diffN % 60;
	if($diffNM<10){
		$diffNM = "0".$diffNM;
	}
	$dayLength = floor($diff/60).":".$diffM;
	$nightLength = floor($diffN/60).":".$diffNM;
	

	$final['sunRise'] = falseCheck($sunRise);
	$final['sunSet'] = falseCheck($sunSet);

	function falseCheck($var){
		if($var!==false){
			return $var;
		}
		else{
			return "";
		}
	}
 
        // Calculation of MonthlyRain-information, concept-file provided by Jachym
        // No error report, but also no reaction detected, besides output = value from first line

$thisMonthRain = 0;
$thisY = date("Y");
$thisM = date("n");
    $result = mysqli_query($con, "
        SELECT DailyRain
FROM (
        SELECT DATETIME, MAX(R) AS DailyRain
        FROM alldata
        WHERE YEAR(DATETIME)=".$thisY." AND MONTH(DATETIME)=".$thisM."
        GROUP BY YEAR(DATETIME), MONTH(DATETIME), DAY(DATETIME)
        ORDER BY DATETIME
     ) AS DailyMaxTable");
    while ($row = mysqli_fetch_array($result)) {
        $thisMonthRain = $thisMonthRain + $row['DailyRain)'];
    }

       // Calculate precipitation this month, extracted from /template/pages/station/liveDataAjax.php

$data['monthRains'] = array();
     $result = mysqli_query($con, "
	 SELECT  max(R)
         FROM  alldata
	 WHERE YEAR(DateTime) = YEAR(CURDATE()) AND MONTH(DateTime) = MONTH(CURDATE())
	 GROUP BY YEAR(DateTime), MONTH(DateTime), DAY(DateTime)
	 "
	);
	while ($row = mysqli_fetch_array($result)) {
		array_push($data['monthRains'], convertR($row['max(R)']));		
	}
	if(isset($data['monthRains'])){
		$data['monthAvgR'] = array_sum($data['monthRains'])/count($data['monthRains']);
		$data['monthMaxR'] = max($data['monthRains']);
	}
	$data['monthR'] = array_sum($data['monthRains']);
		
	// Calculate precipitation this year
	$data['yearRains'] = array();
	$result = mysqli_query($con, "
			SELECT  max(R)
			FROM  alldata
			WHERE YEAR(DateTime) = YEAR(CURDATE())
			GROUP BY YEAR(DateTime), MONTH(DateTime), DAY(DateTime)
			"
	);
	while ($row = mysqli_fetch_array($result)) {
		array_push($data['yearRains'], convertR($row['max(R)']));		
	}
	if(empty($data['yearRains'])===false){
		$data['yearAvgR'] = array_sum($data['yearRains'])/count($data['yearRains']);
		$data['yearMaxR'] = max($data['yearRains']);
	}
	$data['yearR'] = array_sum($data['yearRains']);

        //Calculation of Wind-information [average value over 10 minutes], based on concept-file provided by Jachym

$wind10avg = array();
    $result = mysqli_query($con, "
        SELECT  W
FROM  alldata
WHERE DateTime >= now() - interval 10 minute
ORDER BY DateTime DESC
    ");
    while ($row = mysqli_fetch_array($result)) {
         $wind10avg[] = $row['W'];	
		 }
    if((array_sum($wind10avg) > 0) && (count($wind10avg) > 0)){
         $wind10avg = array_sum($wind10avg) / count($wind10avg);
         }
    else if(array_sum($wind10avg)== 0){
//         $wind10avg = number_format("0.0",1,".","");
         $wind10avg = "0.0";
         }
    else{
         $wind10avg = "---";
    }

	// determine barotrend, 'borrowed & adapted' from /template/pages/station/liveMesodata.php

	$resultSQLBaro = mysqli_query($con, "
			SELECT  DateTime, P
			FROM  alldata
			WHERE DateTime <= now() - interval 3 hour
			ORDER BY DateTime DESC
			LIMIT 1
			"
	);
	while($row = mysqli_fetch_array($resultSQLBaro)){
		$pressure3h = convertP($row['P']);
	}
	
	$pressureDifference = $current['P'] - $pressure3h;
	
	if($displayPressUnits=='hpa'){
		if(abs($pressureDifference)<=0.6){
			$baroTrend = "Stabiel";
		}
		else if($pressureDifference>0.6 && $pressureDifference<2){
			$baroTrend = "Langzaam Stijgend";
		}
		else if($pressureDifference >= 2){
			$baroTrend = "Snel Stijgend";
		}
		else if($pressureDifference<-0.6 && $pressureDifference>-2){
			$baroTrend = "Langzaam Dalend";
		}
		else if($pressureDifference <= -2){
			$baroTrend = "Snel Dalend";
		}
		else{
		}
	}
	if($displayPressUnits=='inhg'){
		if(abs($pressureDifference)<=0.02){
			$baroTrend = "Steady";
		}
		else if($pressureDifference>0.02 && $pressureDifference<0.06){
			$baroTrend = "Rising Slowly / Langzaam Stijgend";
		}
		else if($pressureDifference >= 0.06){
			$baroTrend = "Rising Rapidly / Snel Stijgend";
		}
		else if($pressureDifference<-0.02 && $pressureDifference>-0.06){
			$baroTrend = "Falling Slowly / Langzaam Dalend";
		}
		else if($pressureDifference <= -0.06){
			$baroTrend = "Falling Rapidly / Snel Dalend";
		}
		else{
		}
	}
	if($displayPressUnits=='mmhg'){
		if(abs($pressureDifference)<=0.5){
			$baroTrend = "Steady";
		}
		else if($pressureDifference>0.5 && $pressureDifference<1.5){
			$baroTrend = "Rising Slowly / Langzaam Stijgend";
		}
		else if($pressureDifference >= 1.5){
			$baroTrend = "Rising Rapidly / Snel Stijgend";
		}
		else if($pressureDifference<-0.5 && $pressureDifference>-1.5){
			$baroTrend = "Falling Slowly / Langzaam Dalend";
		}
		else if($pressureDifference <= -1.5){
			$baroTrend = "Falling Rapidly / Snel Dalend";
		}
		else{
		}
	}

       // Calculation of HeatIndex & WindChill, extracted from /template/pages/station/liveMesodata.php

function calcHeatIndex($temp,$humidity,$tempUOM) {
// Calculate Heat Index from temperature and humidity
// Source of calculation: http://woody.cowpi.com/phpscripts/getwx.php.txt	
  if(preg_match('|C|i',$tempUOM)) {
    $tempF = round(1.8 * $temp + 32,1);
  } else {
	$tempF = round($temp,1);
  }
  $rh = $humidity;
  
  // Calculate Heat Index based on temperature in F and relative humidity (65 = 65%)
  if ($tempF > 79 && $rh > 39) {
	  $hiF = -42.379 + 2.04901523 * $tempF + 10.14333127 * $rh - 0.22475541 * $tempF * $rh;
	  $hiF += -0.00683783 * pow($tempF, 2) - 0.05481717 * pow($rh, 2);
	  $hiF += 0.00122874 * pow($tempF, 2) * $rh + 0.00085282 * $tempF * pow($rh, 2);
	  $hiF += -0.00000199 * pow($tempF, 2) * pow($rh, 2);
	  $hiF = round($hiF,1);
	  $hiC = round(($hiF - 32) / 1.8,1);
  } else {
	  $hiF = $tempF;
	  $hiC = round(($hiF - 32) / 1.8,1);
  }
  if(preg_match('|F|i',$useunit)) {
     $heatIndex = $hiF;	  
  } else {
	 $heatIndex = $hiC;
  }
  return($heatIndex);	
}

function calcWindChill($temp,$wind,$tempUOM,$windUOM) {
  // Calculate Wind Chill Temperature based on temperature in F and
  // wind speed in miles per hour
  // Source of calculation: http://woody.cowpi.com/phpscripts/getwx.php.txt	
  if(preg_match('|C|i',$tempUOM)) {
    $tempF = round(1.8 * $temp + 32,1);
  } else {
	$tempF = round($temp,1);
  }
  // ms, kmh, kt or mph 
  if(preg_match('|mph|i',$windUOM)) {
	 $windspeed = round($wind,0);
  } elseif (preg_match('|km|i',$windUOM)) {
	 $windspeed = round(0.621371 * $wind,0);
   } elseif (preg_match('|kt|i',$windUOM)) {
	 $windspeed = round(1.15078 * $wind,0);
  } elseif (preg_match('|ms|i',$windUOM)) {
	 $windspeed = round(2.23694 * $wind,0);
  } else {
	 $windspeed = 0;
  }
  
  
  if ($tempF < 51 && $windspeed > 3) {
		  $chillF = 35.74 + 0.6215 * $tempF - 35.75 * pow($windspeed, 0.16) + 0.4275 * $tempF * pow($windspeed, 0.16);
		  $chillF = round($chillF);
		  $chillC = round(($chillF - 32) / 1.8);
		  $wxInfo['WIND CHILL'] = "$chillF&deg;F ($chillC&deg;C)";
  } else {
	  return($temp);
  }

  if(preg_match('|C|i',$tempUOM)) {
	  $chill = $chillC;
  } else {
	  $chill = $chillF;
  }
  return($chill);
	
}

  // Calculation of HeatIndex and WindChill for HWAFeed-Output using above 2 functions

  // FunctionCall = calcHeatIndex($temp,$humidity,$tempUOM)

$HWA_HeatIndex = calcHeatIndex($current['T'],$current['H'],$displayTempUnits);

  // FunctionCall = calcWindChill($temp,$wind,$tempUOM,$windUOM)

$HWA_WindChill = calcWindChill($current['T'],$current['W'],$displayTempUnits,$displayWindUnits);

?>
BOF

$version = "00, Release 22";

$dataSource ="<?php echo $apiData['SW']?>";
$stationName = "<?php echo $pageName?>";
$stationModel = "<?php echo $stationModel?>";
$stationLocation = "<?php echo $stationLocation?>";
$stationLon = "<?php echo $lon?>";
$stationLat = "<?php echo $lat?>";

$date = "<?php echo date('d/m/Y')?>";
$time = "<?php echo date('H:i')?>";
$stationDate = "<?php echo date('d-m-Y',$current['UNIX'])?>";
$stationTime = "<?php echo date('H:i',$current['UNIX'])?>";
$utcdate = "<?php echo gmdate("d-m-Y",$current['UNIX'])?>";
$utctime = "<?php echo gmdate("H:i",$current['UNIX'])?>";

$tempUnit = "<?php echo $displayTempUnits?>";
$humUnit = "%";
$barUnit = "<?php echo steelUnits($displayPressUnits)?>";
$rainUnit = "<?php echo $displayRainUnits?>";
$rateUnit = "mm/h";
$windUnit = "km/h";

$sunriseTime = "<?php echo $final['sunRise']?>";
$sunsetTime = "<?php echo $final['sunSet']?>";

$outsideTemp = "<?php echo number_format($current['T'],1,".","")?>";
$lowOutsideTemp = "<?php echo number_format($today['minT'],1,".","")?>";
$hiOutsideTemp = "<?php echo number_format($today['maxT'],1,".","")?>";
$lowOutsideTempTime = "<?php echo date("H:i", strtotime($today['minTTime']))?>";
$hiOutsideTempTime = "<?php echo date("H:i", strtotime($today['maxTTime']))?>";

$outsideHumidity = "<?php echo number_format($current['H'],1,".","")?>";
$lowHumidity = "<?php echo number_format($today['minH'],1,".","")?>";
$hiHumidity = "<?php echo number_format($today['maxH'],1,".","")?>";
$lowHumidityTime = "<?php echo date("H:i", strtotime($today['minHTime']))?>";
$hiHumidityTime = "<?php echo date("H:i", strtotime($today['maxHTime']))?>";

$outsideDewPt = "<?php echo number_format($current['D'],1,".","")?>";
$lowDewpoint = "<?php echo number_format($today['minD'],1,".","")?>";
$hiDewpoint = "<?php echo number_format($today['maxD'],1,".","")?>";
$lowDewpointTime = "<?php echo date("H:i", strtotime($today['minDTime']))?>";
$hiDewpointTime = "<?php echo date("H:i", strtotime($today['maxDTime']))?>";

$windSpeed = "<?php echo number_format($current['W'],1,".","")?>";
$wind10Avg = "<?php echo $wind10avg?>"; 
$hiWindSpeed = "<?php echo number_format($today['maxG'],1,".","")?>";
$hiWindSpeedTime = "<?php echo date("H:i", strtotime($today['maxGTime']))?>";

$windDir = "<?php echo number_format($current['B'],0,".","")?>";
$windDirection = "<?php echo windAbb($current['B'])?>";

$windChill = "<?php echo number_format($HWA_WindChill,1,".","")?>";
$windChill_AT = "<?php echo number_format($current['A'],1,".","")?>";
$lowWindchill = "<?php echo number_format($today['minA'],1,".","")?>";
$lowWindchillTime = "<?php echo date("H:i", strtotime($today['minATime']))?>";

$outsideHeatIndex = "<?php echo number_format($HWA_HeatIndex,1,".","")?>";
$outsideHeatIndex_AT = "<?php echo number_format($current['A'],1,".","")?>";
$hiHeatIndex = "<?php echo number_format($today['maxA'],1,".","")?>";
$hiHeatIndexTime = "<?php echo date("H:i", strtotime($today['maxATime']))?>";

$barTrend = "<?php echo $baroTrend?>";

$barometer = "<?php echo number_format($current['P'],$decimalsP,".","")?>";
$lowBarometer = "<?php echo number_format($today['minP'],$decimalsP,".","")?>";
$hiBarometer = "<?php echo number_format($today['maxP'],$decimalsP,".","")?>";
$lowBarometerTime = "<?php echo date("H:i", strtotime($today['minPTime']))?>";
$hiBarometerTime = "<?php echo date("H:i", strtotime($today['maxPTime']))?>";

$stormRain = "---";
$dailyRain = "<?php echo number_format($current['R'],$decimalsR,".","")?>";
$monthlyRain = "<?php echo number_format($data['monthR'],$decimalsR,".","")?>";
$totalRain = "<?php echo number_format($data['yearR'],$decimalsR,".","")?>";
$rainRate = "<?php echo number_format($current['RR'],$decimalsR,".","")?>";
$hiRainRate = "<?php echo number_format($today['maxRR'],$decimalsR,".","")?>";
$hiRainRateTime = "<?php echo date("H:i", strtotime($today['maxRRTime']))?>";

$solarRad = "<?php echo number_format($current['S'],0,".","")?>";
$hiSolarRad = "<?php echo number_format($today['maxS'],0,".","")?>";
$hiSolarRadTime = "<?php echo date("H:i", strtotime($today['maxSTime']))?>";
$sunshine = "<?php echo number_format($current['SS'],1,".","")?>";

$uv = "<?php echo $current['UV']; ?>";

$hiUV uit cache = "<?php echo $uvfromcache['maxdata'];?>";
$hiUVTime uit cache = "<?php echo $uvfromcache['maxtime'];?>";
$hiUV uit db = "<?php echo $maxUVToday ?>";
$hiUVTime uit db = "<?php if ($maxUVtime == '---') {echo $maxUVtime;} else 
							echo date("H:i", strtotime($maxUVtime)) ?>";
<? 
//check hwa hiUV from cache or db
if ($uvdatabase == 1) {		
		$hiUV = $maxUVToday;
		$hiUVTime = date("H:i", strtotime($maxUVtime));
	} elseif  ($uvcache == 1) {
		$hiUV = $uvfromcache['maxdata'];
		$hiUVTime = $uvfromcache['maxtime'];	
	}
?>

$hiUV = "<?php echo $hiUV;?>";
$hiUVTime = "<?php echo $hiUVTime;?>";
EOF
